==> qtjambi-help-5.15-sources.jar: io/qt/help/QHelpEngine.java <==
package io.qt.help;


/**
 * <p>Access to contents and indices of the help engine</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qhelpengine.html">QHelpEngine</a></p>
 */
public class QHelpEngine extends io.qt.help.QHelpEngineCore
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QHelpEngine.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QHelpEngine(java.lang.String, io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QHelpEngine(java.lang.String collectionFile) {
        this(collectionFile, (io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qhelpengine.html#QHelpEngine">QHelpEngine::QHelpEngine(QString,QObject*)</a></p>
     */
    public QHelpEngine(java.lang.String collectionFile, io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, collectionFile, parent);
        if (parent != null) QtJambi_LibraryUtilities.internal.setCppOwnership(this);
    }
    
    private native static void initialize_native(QHelpEngine instance, java.lang.String collectionFile, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qhelpengine.html#contentModel">QHelpEngine::contentModel()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.help.QHelpContentModel contentModel(){
        return contentModel_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.help.QHelpContentModel contentModel_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qhelpengine.html#contentWidget">QHelpEngine::contentWidget()</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.help.QHelpContentWidget contentWidget(){
        return contentWidget_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.help.QHelpContentWidget contentWidget_native(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qhelpengine.html#indexModel">QHelpEngine::indexModel()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.help.QHelpIndexModel indexModel(){
        return indexModel_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.help.QHelpIndexModel indexModel_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qhelpengine.html#indexWidget">QHelpEngine::indexWidget()</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.help.QHelpIndexWidget indexWidget(){
        return indexWidget_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.help.QHelpIndexWidget indexWidget_native(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qhelpengine.html#searchEngine">QHelpEngine::searchEngine()</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.help.QHelpSearchEngine searchEngine(){
        return searchEngine_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.help.QHelpSearchEngine searchEngine_native(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QHelpEngine(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-help-6.2.1-sources.jar: io/qt/help/QHelpEngine.java <==
package io.qt.help;


/**
 * <p>Access to contents and indices of the help engine</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qhelpengine.html">QHelpEngine</a></p>
 */
public class QHelpEngine extends io.qt.help.QHelpEngineCore
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QHelpEngine.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QHelpEngine(java.lang.String, io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QHelpEngine(java.lang.String collectionFile) {
        this(collectionFile, (io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpengine.html#QHelpEngine">QHelpEngine::QHelpEngine(QString,QObject*)</a></p>
     */
    public QHelpEngine(java.lang.String collectionFile, io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, collectionFile, parent);
        if (parent != null) QtJambi_LibraryUtilities.internal.setCppOwnership(this);
    }
    
    private native static void initialize_native(QHelpEngine instance, java.lang.String collectionFile, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpengine.html#contentModel">QHelpEngine::contentModel()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.help.QHelpContentModel contentModel(){
        return contentModel_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.help.QHelpContentModel contentModel_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpengine.html#contentWidget">QHelpEngine::contentWidget()</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.help.QHelpContentWidget contentWidget(){
        return contentWidget_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.help.QHelpContentWidget contentWidget_native(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpengine.html#indexModel">QHelpEngine::indexModel()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.help.QHelpIndexModel indexModel(){
        return indexModel_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.help.QHelpIndexModel indexModel_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpengine.html#indexWidget">QHelpEngine::indexWidget()</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.help.QHelpIndexWidget indexWidget(){
        return indexWidget_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.help.QHelpIndexWidget indexWidget_native(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpengine.html#searchEngine">QHelpEngine::searchEngine()</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.help.QHelpSearchEngine searchEngine(){
        return searchEngine_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.help.QHelpSearchEngine searchEngine_native(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QHelpEngine(QPrivateConstructor p) { super(p); } 
    
}
